<a id="mypy-boto3-comprehend"></a>

# mypy-boto3-comprehend

[![PyPI - mypy-boto3-comprehend](https://img.shields.io/pypi/v/mypy-boto3-comprehend.svg?color=blue)](https://pypi.org/project/mypy-boto3-comprehend)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-comprehend.svg?color=blue)](https://pypi.org/project/mypy-boto3-comprehend)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/mypy-boto3-comprehend?color=blue)](https://pypistats.org/packages/mypy-boto3-comprehend)

![boto3.typed](https://github.com/youtype/mypy_boto3_builder/raw/main/logo.png)

Type annotations for
[boto3.Comprehend 1.26.99](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/comprehend.html#Comprehend)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 7.14.2](https://github.com/youtype/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-comprehend docs](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehend/).

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/youtype/mypy_boto3_builder/raw/main/demo.gif)

- [mypy-boto3-comprehend](#mypy-boto3-comprehend)
  - [How to install](#how-to-install)
    - [VSCode extension](#vscode-extension)
    - [From PyPI with pip](#from-pypi-with-pip)
  - [How to uninstall](#how-to-uninstall)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Emacs](#emacs)
    - [Sublime Text](#sublime-text)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [How it works](#how-it-works)
  - [What's new](#what's-new)
    - [Implemented features](#implemented-features)
    - [Latest changes](#latest-changes)
  - [Versioning](#versioning)
  - [Thank you](#thank-you)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

<a id="vscode-extension"></a>

### VSCode extension

Add
[AWS Boto3](https://marketplace.visualstudio.com/items?itemName=Boto3typed.boto3-ide)
extension to your VSCode and run `AWS boto3: Quick Start` command.

Click `Modify` and select `boto3 common` and `Comprehend`.

<a id="from-pypi-with-pip"></a>

### From PyPI with pip

Install `boto3-stubs` for `Comprehend` service.

```bash
# install with boto3 type annotations
python -m pip install 'boto3-stubs[comprehend]'


# Lite version does not provide session.client/resource overloads
# it is more RAM-friendly, but requires explicit type annotations
python -m pip install 'boto3-stubs-lite[comprehend]'


# standalone installation
python -m pip install mypy-boto3-comprehend
```

<a id="how-to-uninstall"></a>

## How to uninstall

```bash
python -m pip uninstall -y mypy-boto3-comprehend
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto3-stubs[comprehend]` in your environment:

```bash
python -m pip install 'boto3-stubs[comprehend]'
```

Both type checking and code completion should now work. No explicit type
annotations required, write your `boto3` code as usual.

<a id="pycharm"></a>

### PyCharm

Install `boto3-stubs-lite[comprehend]` in your environment:

```bash
python -m pip install 'boto3-stubs-lite[comprehend]'`
```

Both type checking and code completion should now work. Explicit type
annotations **are required**.

Use `boto3-stubs` package instead for implicit type discovery.

<a id="emacs"></a>

### Emacs

- Install `boto3-stubs` with services you use in your environment:

```bash
python -m pip install 'boto3-stubs[comprehend]'
```

- Install [use-package](https://github.com/jwiegley/use-package),
  [lsp](https://github.com/emacs-lsp/lsp-mode/),
  [company](https://github.com/company-mode/company-mode) and
  [flycheck](https://github.com/flycheck/flycheck) packages
- Install [lsp-pyright](https://github.com/emacs-lsp/lsp-pyright) package

```elisp
(use-package lsp-pyright
  :ensure t
  :hook (python-mode . (lambda ()
                          (require 'lsp-pyright)
                          (lsp)))  ; or lsp-deferred
  :init (when (executable-find "python3")
          (setq lsp-pyright-python-executable-cmd "python3"))
  )
```

- Make sure emacs uses the environment where you have installed `boto3-stubs`

Type checking should now work. No explicit type annotations required, write
your `boto3` code as usual.

<a id="sublime-text"></a>

### Sublime Text

- Install `boto3-stubs[comprehend]` with services you use in your environment:

```bash
python -m pip install 'boto3-stubs[comprehend]'
```

- Install [LSP-pyright](https://github.com/sublimelsp/LSP-pyright) package

Type checking should now work. No explicit type annotations required, write
your `boto3` code as usual.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto3-stubs[comprehend]` in your environment:

```bash
python -m pip install 'boto3-stubs[comprehend]'`
```

Type checking should now work. No explicit type annotations required, write
your `boto3` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `npm i -g pyright`
- Install `boto3-stubs[comprehend]` in your environment:

```bash
python -m pip install 'boto3-stubs[comprehend]'
```

Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should now work. No explicit type annotations required, write
your `boto3` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`ComprehendClient` provides annotations for `boto3.client("comprehend")`.

```python
from boto3.session import Session

from mypy_boto3_comprehend import ComprehendClient

client: ComprehendClient = Session().client("comprehend")

# now client usage is checked by mypy and IDE should provide code completion
```

<a id="paginators-annotations"></a>

### Paginators annotations

`mypy_boto3_comprehend.paginator` module contains type annotations for all
paginators.

```python
from boto3.session import Session

from mypy_boto3_comprehend import ComprehendClient
from mypy_boto3_comprehend.paginator import (
    ListDocumentClassificationJobsPaginator,
    ListDocumentClassifiersPaginator,
    ListDominantLanguageDetectionJobsPaginator,
    ListEndpointsPaginator,
    ListEntitiesDetectionJobsPaginator,
    ListEntityRecognizersPaginator,
    ListKeyPhrasesDetectionJobsPaginator,
    ListPiiEntitiesDetectionJobsPaginator,
    ListSentimentDetectionJobsPaginator,
    ListTopicsDetectionJobsPaginator,
)

client: ComprehendClient = Session().client("comprehend")

# Explicit type annotations are optional here
# Types should be correctly discovered by mypy and IDEs
list_document_classification_jobs_paginator: ListDocumentClassificationJobsPaginator = (
    client.get_paginator("list_document_classification_jobs")
)
list_document_classifiers_paginator: ListDocumentClassifiersPaginator = client.get_paginator(
    "list_document_classifiers"
)
list_dominant_language_detection_jobs_paginator: ListDominantLanguageDetectionJobsPaginator = (
    client.get_paginator("list_dominant_language_detection_jobs")
)
list_endpoints_paginator: ListEndpointsPaginator = client.get_paginator("list_endpoints")
list_entities_detection_jobs_paginator: ListEntitiesDetectionJobsPaginator = client.get_paginator(
    "list_entities_detection_jobs"
)
list_entity_recognizers_paginator: ListEntityRecognizersPaginator = client.get_paginator(
    "list_entity_recognizers"
)
list_key_phrases_detection_jobs_paginator: ListKeyPhrasesDetectionJobsPaginator = (
    client.get_paginator("list_key_phrases_detection_jobs")
)
list_pii_entities_detection_jobs_paginator: ListPiiEntitiesDetectionJobsPaginator = (
    client.get_paginator("list_pii_entities_detection_jobs")
)
list_sentiment_detection_jobs_paginator: ListSentimentDetectionJobsPaginator = client.get_paginator(
    "list_sentiment_detection_jobs"
)
list_topics_detection_jobs_paginator: ListTopicsDetectionJobsPaginator = client.get_paginator(
    "list_topics_detection_jobs"
)
```

<a id="literals"></a>

### Literals

`mypy_boto3_comprehend.literals` module contains literals extracted from shapes
that can be used in user code for type checking.

```python
from mypy_boto3_comprehend.literals import (
    AugmentedManifestsDocumentTypeFormatType,
    BlockTypeType,
    DatasetDataFormatType,
    DatasetStatusType,
    DatasetTypeType,
    DocumentClassifierDataFormatType,
    DocumentClassifierModeType,
    DocumentReadActionType,
    DocumentReadFeatureTypesType,
    DocumentReadModeType,
    DocumentTypeType,
    EndpointStatusType,
    EntityRecognizerDataFormatType,
    EntityTypeType,
    FlywheelIterationStatusType,
    FlywheelStatusType,
    InputFormatType,
    JobStatusType,
    LanguageCodeType,
    ListDocumentClassificationJobsPaginatorName,
    ListDocumentClassifiersPaginatorName,
    ListDominantLanguageDetectionJobsPaginatorName,
    ListEndpointsPaginatorName,
    ListEntitiesDetectionJobsPaginatorName,
    ListEntityRecognizersPaginatorName,
    ListKeyPhrasesDetectionJobsPaginatorName,
    ListPiiEntitiesDetectionJobsPaginatorName,
    ListSentimentDetectionJobsPaginatorName,
    ListTopicsDetectionJobsPaginatorName,
    ModelStatusType,
    ModelTypeType,
    PageBasedErrorCodeType,
    PartOfSpeechTagTypeType,
    PiiEntitiesDetectionMaskModeType,
    PiiEntitiesDetectionModeType,
    PiiEntityTypeType,
    RelationshipTypeType,
    SentimentTypeType,
    SplitType,
    SyntaxLanguageCodeType,
    TargetedSentimentEntityTypeType,
    ComprehendServiceName,
    ServiceName,
    ResourceServiceName,
    PaginatorName,
    RegionName,
)


def check_value(value: AugmentedManifestsDocumentTypeFormatType) -> bool:
    ...
```

<a id="typed-dictionaries"></a>

### Typed dictionaries

`mypy_boto3_comprehend.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from mypy_boto3_comprehend.type_defs import (
    AugmentedManifestsListItemTypeDef,
    DominantLanguageTypeDef,
    BatchDetectDominantLanguageRequestRequestTypeDef,
    BatchItemErrorTypeDef,
    ResponseMetadataTypeDef,
    BatchDetectEntitiesRequestRequestTypeDef,
    KeyPhraseTypeDef,
    BatchDetectKeyPhrasesRequestRequestTypeDef,
    SentimentScoreTypeDef,
    BatchDetectSentimentRequestRequestTypeDef,
    BatchDetectSyntaxRequestRequestTypeDef,
    BatchDetectTargetedSentimentRequestRequestTypeDef,
    ChildBlockTypeDef,
    RelationshipsListItemTypeDef,
    BoundingBoxTypeDef,
    ClassifierEvaluationMetricsTypeDef,
    DocumentReaderConfigTypeDef,
    DocumentClassTypeDef,
    DocumentLabelTypeDef,
    DocumentTypeListItemTypeDef,
    ErrorsListItemTypeDef,
    ContainsPiiEntitiesRequestRequestTypeDef,
    EntityLabelTypeDef,
    TagTypeDef,
    DocumentClassifierOutputDataConfigTypeDef,
    VpcConfigTypeDef,
    DatasetAugmentedManifestsListItemTypeDef,
    DatasetDocumentClassifierInputDataConfigTypeDef,
    DatasetEntityRecognizerAnnotationsTypeDef,
    DatasetEntityRecognizerDocumentsTypeDef,
    DatasetEntityRecognizerEntityListTypeDef,
    DatasetFilterTypeDef,
    DatasetPropertiesTypeDef,
    DeleteDocumentClassifierRequestRequestTypeDef,
    DeleteEndpointRequestRequestTypeDef,
    DeleteEntityRecognizerRequestRequestTypeDef,
    DeleteFlywheelRequestRequestTypeDef,
    DeleteResourcePolicyRequestRequestTypeDef,
    DescribeDatasetRequestRequestTypeDef,
    DescribeDocumentClassificationJobRequestRequestTypeDef,
    DescribeDocumentClassifierRequestRequestTypeDef,
    DescribeDominantLanguageDetectionJobRequestRequestTypeDef,
    DescribeEndpointRequestRequestTypeDef,
    EndpointPropertiesTypeDef,
    DescribeEntitiesDetectionJobRequestRequestTypeDef,
    DescribeEntityRecognizerRequestRequestTypeDef,
    DescribeEventsDetectionJobRequestRequestTypeDef,
    DescribeFlywheelIterationRequestRequestTypeDef,
    DescribeFlywheelRequestRequestTypeDef,
    DescribeKeyPhrasesDetectionJobRequestRequestTypeDef,
    DescribePiiEntitiesDetectionJobRequestRequestTypeDef,
    DescribeResourcePolicyRequestRequestTypeDef,
    DescribeSentimentDetectionJobRequestRequestTypeDef,
    DescribeTargetedSentimentDetectionJobRequestRequestTypeDef,
    DescribeTopicsDetectionJobRequestRequestTypeDef,
    DetectDominantLanguageRequestRequestTypeDef,
    DetectKeyPhrasesRequestRequestTypeDef,
    DetectPiiEntitiesRequestRequestTypeDef,
    PiiEntityTypeDef,
    DetectSentimentRequestRequestTypeDef,
    DetectSyntaxRequestRequestTypeDef,
    DetectTargetedSentimentRequestRequestTypeDef,
    DocumentClassificationConfigTypeDef,
    DocumentClassificationJobFilterTypeDef,
    OutputDataConfigTypeDef,
    DocumentClassifierFilterTypeDef,
    DocumentClassifierSummaryTypeDef,
    ExtractedCharactersListItemTypeDef,
    DominantLanguageDetectionJobFilterTypeDef,
    EndpointFilterTypeDef,
    EntitiesDetectionJobFilterTypeDef,
    EntityTypesListItemTypeDef,
    EntityRecognizerAnnotationsTypeDef,
    EntityRecognizerDocumentsTypeDef,
    EntityRecognizerEntityListTypeDef,
    EntityRecognizerEvaluationMetricsTypeDef,
    EntityRecognizerFilterTypeDef,
    EntityTypesEvaluationMetricsTypeDef,
    EntityRecognizerOutputDataConfigTypeDef,
    EntityRecognizerSummaryTypeDef,
    EventsDetectionJobFilterTypeDef,
    FlywheelFilterTypeDef,
    FlywheelIterationFilterTypeDef,
    FlywheelModelEvaluationMetricsTypeDef,
    FlywheelSummaryTypeDef,
    PointTypeDef,
    KeyPhrasesDetectionJobFilterTypeDef,
    PaginatorConfigTypeDef,
    ListDocumentClassifierSummariesRequestRequestTypeDef,
    ListEntityRecognizerSummariesRequestRequestTypeDef,
    PiiEntitiesDetectionJobFilterTypeDef,
    SentimentDetectionJobFilterTypeDef,
    ListTagsForResourceRequestRequestTypeDef,
    TargetedSentimentDetectionJobFilterTypeDef,
    TopicsDetectionJobFilterTypeDef,
    PartOfSpeechTagTypeDef,
    PiiOutputDataConfigTypeDef,
    RedactionConfigTypeDef,
    PutResourcePolicyRequestRequestTypeDef,
    StartFlywheelIterationRequestRequestTypeDef,
    StopDominantLanguageDetectionJobRequestRequestTypeDef,
    StopEntitiesDetectionJobRequestRequestTypeDef,
    StopEventsDetectionJobRequestRequestTypeDef,
    StopKeyPhrasesDetectionJobRequestRequestTypeDef,
    StopPiiEntitiesDetectionJobRequestRequestTypeDef,
    StopSentimentDetectionJobRequestRequestTypeDef,
    StopTargetedSentimentDetectionJobRequestRequestTypeDef,
    StopTrainingDocumentClassifierRequestRequestTypeDef,
    StopTrainingEntityRecognizerRequestRequestTypeDef,
    UntagResourceRequestRequestTypeDef,
    UpdateEndpointRequestRequestTypeDef,
    DocumentClassifierInputDataConfigTypeDef,
    BatchDetectDominantLanguageItemResultTypeDef,
    CreateDatasetResponseTypeDef,
    CreateDocumentClassifierResponseTypeDef,
    CreateEndpointResponseTypeDef,
    CreateEntityRecognizerResponseTypeDef,
    CreateFlywheelResponseTypeDef,
    DescribeResourcePolicyResponseTypeDef,
    DetectDominantLanguageResponseTypeDef,
    ImportModelResponseTypeDef,
    PutResourcePolicyResponseTypeDef,
    StartDocumentClassificationJobResponseTypeDef,
    StartDominantLanguageDetectionJobResponseTypeDef,
    StartEntitiesDetectionJobResponseTypeDef,
    StartEventsDetectionJobResponseTypeDef,
    StartFlywheelIterationResponseTypeDef,
    StartKeyPhrasesDetectionJobResponseTypeDef,
    StartPiiEntitiesDetectionJobResponseTypeDef,
    StartSentimentDetectionJobResponseTypeDef,
    StartTargetedSentimentDetectionJobResponseTypeDef,
    StartTopicsDetectionJobResponseTypeDef,
    StopDominantLanguageDetectionJobResponseTypeDef,
    StopEntitiesDetectionJobResponseTypeDef,
    StopEventsDetectionJobResponseTypeDef,
    StopKeyPhrasesDetectionJobResponseTypeDef,
    StopPiiEntitiesDetectionJobResponseTypeDef,
    StopSentimentDetectionJobResponseTypeDef,
    StopTargetedSentimentDetectionJobResponseTypeDef,
    UpdateEndpointResponseTypeDef,
    BatchDetectKeyPhrasesItemResultTypeDef,
    DetectKeyPhrasesResponseTypeDef,
    BatchDetectSentimentItemResultTypeDef,
    DetectSentimentResponseTypeDef,
    MentionSentimentTypeDef,
    BlockReferenceTypeDef,
    ClassifierMetadataTypeDef,
    ClassifyDocumentRequestRequestTypeDef,
    DetectEntitiesRequestRequestTypeDef,
    InputDataConfigTypeDef,
    ContainsPiiEntitiesResponseTypeDef,
    CreateEndpointRequestRequestTypeDef,
    ImportModelRequestRequestTypeDef,
    ListTagsForResourceResponseTypeDef,
    TagResourceRequestRequestTypeDef,
    DataSecurityConfigTypeDef,
    UpdateDataSecurityConfigTypeDef,
    DatasetEntityRecognizerInputDataConfigTypeDef,
    ListDatasetsRequestRequestTypeDef,
    DescribeDatasetResponseTypeDef,
    ListDatasetsResponseTypeDef,
    DescribeEndpointResponseTypeDef,
    ListEndpointsResponseTypeDef,
    DetectPiiEntitiesResponseTypeDef,
    ListDocumentClassificationJobsRequestRequestTypeDef,
    ListDocumentClassifiersRequestRequestTypeDef,
    ListDocumentClassifierSummariesResponseTypeDef,
    DocumentMetadataTypeDef,
    ListDominantLanguageDetectionJobsRequestRequestTypeDef,
    ListEndpointsRequestRequestTypeDef,
    ListEntitiesDetectionJobsRequestRequestTypeDef,
    EntityRecognitionConfigTypeDef,
    EntityRecognizerInputDataConfigTypeDef,
    ListEntityRecognizersRequestRequestTypeDef,
    EntityRecognizerMetadataEntityTypesListItemTypeDef,
    ListEntityRecognizerSummariesResponseTypeDef,
    ListEventsDetectionJobsRequestRequestTypeDef,
    ListFlywheelsRequestRequestTypeDef,
    ListFlywheelIterationHistoryRequestRequestTypeDef,
    FlywheelIterationPropertiesTypeDef,
    ListFlywheelsResponseTypeDef,
    GeometryTypeDef,
    ListKeyPhrasesDetectionJobsRequestRequestTypeDef,
    ListDocumentClassificationJobsRequestListDocumentClassificationJobsPaginateTypeDef,
    ListDocumentClassifiersRequestListDocumentClassifiersPaginateTypeDef,
    ListDominantLanguageDetectionJobsRequestListDominantLanguageDetectionJobsPaginateTypeDef,
    ListEndpointsRequestListEndpointsPaginateTypeDef,
    ListEntitiesDetectionJobsRequestListEntitiesDetectionJobsPaginateTypeDef,
    ListEntityRecognizersRequestListEntityRecognizersPaginateTypeDef,
    ListKeyPhrasesDetectionJobsRequestListKeyPhrasesDetectionJobsPaginateTypeDef,
    ListPiiEntitiesDetectionJobsRequestListPiiEntitiesDetectionJobsPaginateTypeDef,
    ListPiiEntitiesDetectionJobsRequestRequestTypeDef,
    ListSentimentDetectionJobsRequestListSentimentDetectionJobsPaginateTypeDef,
    ListSentimentDetectionJobsRequestRequestTypeDef,
    ListTargetedSentimentDetectionJobsRequestRequestTypeDef,
    ListTopicsDetectionJobsRequestListTopicsDetectionJobsPaginateTypeDef,
    ListTopicsDetectionJobsRequestRequestTypeDef,
    SyntaxTokenTypeDef,
    CreateDocumentClassifierRequestRequestTypeDef,
    BatchDetectDominantLanguageResponseTypeDef,
    BatchDetectKeyPhrasesResponseTypeDef,
    BatchDetectSentimentResponseTypeDef,
    TargetedSentimentMentionTypeDef,
    EntityTypeDef,
    DocumentClassifierPropertiesTypeDef,
    DocumentClassificationJobPropertiesTypeDef,
    DominantLanguageDetectionJobPropertiesTypeDef,
    EntitiesDetectionJobPropertiesTypeDef,
    EventsDetectionJobPropertiesTypeDef,
    KeyPhrasesDetectionJobPropertiesTypeDef,
    PiiEntitiesDetectionJobPropertiesTypeDef,
    SentimentDetectionJobPropertiesTypeDef,
    StartDocumentClassificationJobRequestRequestTypeDef,
    StartDominantLanguageDetectionJobRequestRequestTypeDef,
    StartEntitiesDetectionJobRequestRequestTypeDef,
    StartEventsDetectionJobRequestRequestTypeDef,
    StartKeyPhrasesDetectionJobRequestRequestTypeDef,
    StartPiiEntitiesDetectionJobRequestRequestTypeDef,
    StartSentimentDetectionJobRequestRequestTypeDef,
    StartTargetedSentimentDetectionJobRequestRequestTypeDef,
    StartTopicsDetectionJobRequestRequestTypeDef,
    TargetedSentimentDetectionJobPropertiesTypeDef,
    TopicsDetectionJobPropertiesTypeDef,
    UpdateFlywheelRequestRequestTypeDef,
    DatasetInputDataConfigTypeDef,
    ClassifyDocumentResponseTypeDef,
    TaskConfigTypeDef,
    CreateEntityRecognizerRequestRequestTypeDef,
    EntityRecognizerMetadataTypeDef,
    DescribeFlywheelIterationResponseTypeDef,
    ListFlywheelIterationHistoryResponseTypeDef,
    BlockTypeDef,
    BatchDetectSyntaxItemResultTypeDef,
    DetectSyntaxResponseTypeDef,
    TargetedSentimentEntityTypeDef,
    BatchDetectEntitiesItemResultTypeDef,
    DescribeDocumentClassifierResponseTypeDef,
    ListDocumentClassifiersResponseTypeDef,
    DescribeDocumentClassificationJobResponseTypeDef,
    ListDocumentClassificationJobsResponseTypeDef,
    DescribeDominantLanguageDetectionJobResponseTypeDef,
    ListDominantLanguageDetectionJobsResponseTypeDef,
    DescribeEntitiesDetectionJobResponseTypeDef,
    ListEntitiesDetectionJobsResponseTypeDef,
    DescribeEventsDetectionJobResponseTypeDef,
    ListEventsDetectionJobsResponseTypeDef,
    DescribeKeyPhrasesDetectionJobResponseTypeDef,
    ListKeyPhrasesDetectionJobsResponseTypeDef,
    DescribePiiEntitiesDetectionJobResponseTypeDef,
    ListPiiEntitiesDetectionJobsResponseTypeDef,
    DescribeSentimentDetectionJobResponseTypeDef,
    ListSentimentDetectionJobsResponseTypeDef,
    DescribeTargetedSentimentDetectionJobResponseTypeDef,
    ListTargetedSentimentDetectionJobsResponseTypeDef,
    DescribeTopicsDetectionJobResponseTypeDef,
    ListTopicsDetectionJobsResponseTypeDef,
    CreateDatasetRequestRequestTypeDef,
    CreateFlywheelRequestRequestTypeDef,
    FlywheelPropertiesTypeDef,
    EntityRecognizerPropertiesTypeDef,
    DetectEntitiesResponseTypeDef,
    BatchDetectSyntaxResponseTypeDef,
    BatchDetectTargetedSentimentItemResultTypeDef,
    DetectTargetedSentimentResponseTypeDef,
    BatchDetectEntitiesResponseTypeDef,
    DescribeFlywheelResponseTypeDef,
    UpdateFlywheelResponseTypeDef,
    DescribeEntityRecognizerResponseTypeDef,
    ListEntityRecognizersResponseTypeDef,
    BatchDetectTargetedSentimentResponseTypeDef,
)


def get_structure() -> AugmentedManifestsListItemTypeDef:
    return {...}
```

<a id="how-it-works"></a>

## How it works

Fully automated
[mypy-boto3-builder](https://github.com/youtype/mypy_boto3_builder) carefully
generates type annotations for each service, patiently waiting for `boto3`
updates. It delivers drop-in type annotations for you and makes sure that:

- All available `boto3` services are covered.
- Each public class and method of every `boto3` service gets valid type
  annotations extracted from `botocore` schemas.
- Type annotations include up-to-date documentation.
- Link to documentation is provided for every method.
- Code is processed by [black](https://github.com/psf/black) and
  [isort](https://github.com/PyCQA/isort) for readability.

<a id="what's-new"></a>

## What's new

<a id="implemented-features"></a>

### Implemented features

- Fully type annotated `boto3`, `botocore`, `aiobotocore` and `aioboto3`
  libraries
- `mypy`, `pyright`, `VSCode`, `PyCharm`, `Sublime Text` and `Emacs`
  compatibility
- `Client`, `ServiceResource`, `Resource`, `Waiter` `Paginator` type
  annotations for each service
- Generated `TypeDefs` for each service
- Generated `Literals` for each service
- Auto discovery of types for `boto3.client` and `boto3.resource` calls
- Auto discovery of types for `session.client` and `session.resource` calls
- Auto discovery of types for `client.get_waiter` and `client.get_paginator`
  calls
- Auto discovery of types for `ServiceResource` and `Resource` collections
- Auto discovery of types for `aiobotocore.Session.create_client` calls

<a id="latest-changes"></a>

### Latest changes

Builder changelog can be found in
[Releases](https://github.com/youtype/mypy_boto3_builder/releases).

<a id="versioning"></a>

## Versioning

`mypy-boto3-comprehend` version is the same as related `boto3` version and
follows [PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

<a id="thank-you"></a>

## Thank you

- [Allie Fitter](https://github.com/alliefitter) for
  [boto3-type-annotations](https://pypi.org/project/boto3-type-annotations/),
  this package is based on top of his work
- [black](https://github.com/psf/black) developers for an awesome formatting
  tool
- [Timothy Edmund Crosley](https://github.com/timothycrosley) for
  [isort](https://github.com/PyCQA/isort) and how flexible it is
- [mypy](https://github.com/python/mypy) developers for doing all dirty work
  for us
- [pyright](https://github.com/microsoft/pyright) team for the new era of typed
  Python

<a id="documentation"></a>

## Documentation

All services type annotations can be found in
[boto3 docs](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_comprehend/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/youtype/mypy_boto3_builder/issues/)
repository.
